summaryrefslogtreecommitdiff
path: root/toolbin
diff options
context:
space:
mode:
authorRobin Watts <Robin.Watts@artifex.com>2020-11-03 15:21:46 +0000
committerRobin Watts <Robin.Watts@artifex.com>2020-11-03 19:11:57 +0000
commit10036de9c385d900f2ec0312908954ab77664438 (patch)
tree26f2c7ebbea543a3d1811c20d32c0b925b334cc5 /toolbin
parentb4c9f0004f950a7f55fff5777c6fa0d74d1f54bd (diff)
downloadghostpdl-10036de9c385d900f2ec0312908954ab77664438.tar.gz
Update clusterpush.pl for extract jobs.
Diffstat (limited to 'toolbin')
-rwxr-xr-xtoolbin/localcluster/clusterpush.pl20
1 files changed, 16 insertions, 4 deletions
diff --git a/toolbin/localcluster/clusterpush.pl b/toolbin/localcluster/clusterpush.pl
index f7cb9c66c..4fcc1372c 100755
--- a/toolbin/localcluster/clusterpush.pl
+++ b/toolbin/localcluster/clusterpush.pl
@@ -7,7 +7,7 @@ use Data::Dumper;
my $verbose=0;
# bmpcmp usage: [gs] [pcl] [xps] [mupdf] [mujstest] [murun] [mudrawpy] [runtests] [bmpcmp] [arm] [lowres] [highres] [32] [pdfwrite] [ps2write] [xpswrite] [nopdfwrite] [relaxtimeout] [extended] [smoke] [cull] [avx2] [$user] | abort
@@ -25,7 +25,8 @@ my %products=('abort' =>1,
'mujstest'=>1,
'murun'=>1,
'mudrawpy'=>1,
- 'runtests'=>1);
+ 'runtests'=>1,
+ 'extract'=>1);
my $user;
my $product="";
@@ -138,8 +139,17 @@ my $directory=`pwd`;
chomp $directory;
$directory =~ s|.+/||;
-if ($directory ne 'gs' && $directory ne 'ghostpdl' && $directory ne 'mupdf' && $directory ne 'ghostpdl.git' && $directory ne 'mupdf.git') {
+if ($directory ne 'gs' &&
+ $directory ne 'ghostpdl' &&
+ $directory ne 'mupdf' &&
+ $directory ne 'ghostpdl.git' &&
+ $directory ne 'mupdf.git' &&
+ $directory ne 'extract' &&
+ $directory ne 'extract.git') {
$directory="";
+ if (-f "include/extract.h") {
+ $directory='extract';
+ }
if (-d "base" && -d "Resource") {
$directory='gs';
}
@@ -154,11 +164,13 @@ if ($directory ne 'gs' && $directory ne 'ghostpdl' && $directory ne 'mupdf' && $
#$directory="gs" if ($directory eq "" && $product eq "bmpcmp");
$directory="gs" if ($directory eq "" && $product && $product eq "abort");
-die "can't figure out if this is a ghostpdl, gs, or mupdf source directory" if ($directory eq "");
+die "can't figure out if this is a ghostpdl, gs, mupdf or extract source directory" if ($directory eq "");
if (!$product) {
if ($directory eq 'mupdf') {
$product='mupdf';
+ } elsif ($directory eq 'extract') {
+ $product='extract';
} else {
$product='gs pcl xps gpdl'
}
@@ -7,7 +7,7 @@ use Data::Dumper;
my $verbose=0;
-# bmpcmp usage: [gs] [pcl] [xps] [mupdf] [mujstest] [murun] [mudrawpy] [runtests] [bmpcmp] [arm] [lowres] [highres] [32] [pdfwrite] [ps2write] [xpswrite] [nopdfwrite] [relaxtimeout] [extended] [smoke] [cull] [avx2] [$user] | abort
+# bmpcmp usage: [gs] [pcl] [xps] [mupdf] [mujstest] [murun] [mudrawpy] [runtests] [extract] [bmpcmp] [arm] [lowres] [highres] [32] [pdfwrite] [ps2write] [xpswrite] [nopdfwrite] [relaxtimeout] [extended] [smoke] [cull] [avx2] [$user] | abort
'mujstest'=>1,